.. ukt documentation master file, created by
   sphinx-quickstart on Thu Apr 12 18:36:01 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ukt
===

.. image:: logo.png

*ukt* is a fast client library for use with `Kyoto Tycoon <http://fallabs.com/kyototycoon/>`_.
*ukt* is designed to be performant and simple-to-use.

* Full-featured implementation of protocol.
* Performant serialization via C extension.
* Thread-safe and greenlet-safe.
* Socket pooling.
* Simple APIs.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   api
   tuning


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
